@@ -341,7 +341,7 @@ class ArgusService:
 
     def get_groups(self):
         groups = list(ArgusReleaseGroup.all())
-        return sorted(groups, key=lambda g: g.name)
+        return sorted(groups, key=lambda g: g.pretty_name if g.pretty_name else g.name)
 
     def get_tests(self):
         return ArgusReleaseGroupTest.all()
@@ -354,18 +354,6 @@ class ArgusService:
         return release, release_groups, release_tests
 
     def collect_stats(self, release_name: str, limited: bool = False, force: bool = False) -> dict:
-        """
-        Example body:
-        {
-            "master": {
-                "force": true, // Forcefully retrieve stats even if release is disabled
-                "limited": false, // Do not retrieve extra information (last runs, bug reports)
-                "groups": ["longevity", "artifacts"],
-                "tests": ["longevity-100gb", "artifacts-ami"]
-            }
-        }
-        Both groups and tests are considered prefixes to test_run names
-        """
         response = {
             "releases": {
 
@@ -378,6 +366,7 @@ class ArgusService:
             "lastStatus": "unknown",
             "lastInvestigationStatus": "unknown",
             "hasBugReport": False,
+            "disabled": True,
             "tests": None,
         }
 
@@ -407,7 +396,7 @@ class ArgusService:
             "lastInvestigationStatus": "unknown",
             "hasBugReport": False,
             "groups": {
-                group.name: dict(**group_stats_body, group_id=group.id) for group in release_groups
+                group.name: dict(**group_stats_body, group_id=group.id, pretty_name=group.pretty_name) for group in release_groups
             },
             "tests": {},
             "disabled": not release.enabled,
@@ -426,7 +415,13 @@ class ArgusService:
         release_comments = ArgusTestRunComment.filter(release_id=release.id)
         rows = self.session.execute(self.run_by_release_stats_statement, parameters=(release.id,)).all()
         for group, tests in tests_by_group.items():
+            if group.enabled:
+                release_stats["groups"][group.name]["disabled"] = False
+            else:
+                continue
             for test in tests:
+                if not test.enabled:
+                    continue
                 test_group = release_groups_by_id[test.group_id]
                 if not release_stats["groups"][test_group.name]["tests"]:
                     release_stats["groups"][test_group.name]["tests"] = dict()
@@ -453,6 +448,7 @@ class ArgusService:
                 if not run:
                     release_stats["groups"][test_group.name]["tests"][test.name] = {
                         "name": test.name,
+                        "test_id": test.id,
                         "status": "unknown",
                         "group": test_group.name,
                         "start_time": 0,
@@ -1056,15 +1052,18 @@ class ArgusService:
         release = ArgusRelease.get(id=release_id)
         release_comments = list(ReleasePlannerComment.filter(release=release.id).all())
         groups = ArgusReleaseGroup.filter(release_id=release.id).all()
-        groups_by_group_id = {str(group.id): dict(group.items()) for group in groups}
+        groups_by_group_id = {str(group.id): dict(group.items()) for group in groups if group.enabled}
         tests = ArgusReleaseGroupTest.filter(release_id=release.id).all()
-        tests = [dict(t.items()) for t in tests]
+        tests = [dict(t.items()) for t in tests if t.enabled]
         tests_by_group = {}
         for test in tests:
-            test["group_name"] = groups_by_group_id[str(test["group_id"])]["name"]
+            group = groups_by_group_id.get(str(test["group_id"]))
+            if not group:
+                continue
+            test["group_name"] = group["name"]
+            test["pretty_group_name"] = groups_by_group_id[str(test["group_id"])]["pretty_name"]
             try:
-                comment = next(filter(lambda c: c.test == test["id"]
-                               and c.group == test["group_id"], release_comments))
+                comment = next(filter(lambda c: c.test == test["id"], release_comments))
             except StopIteration:
                 comment = None
             test["comment"] = comment.comment if comment else ""
